@@ -1,5 +1,5 @@
 /*
- * This file is part of MPSolve 3.2.1
+ * This file is part of MPSolve 3.2.2
  *
  * Copyright (C) 2001-2020, Dipartimento di Matematica "L. Tonelli", Pisa.
  * License: http://www.gnu.org/licenses/gpl.html GPL version 3 or higher
@@ -15,12 +15,6 @@
 #include <mps/mps.h>
 #include <string.h>
 
-static mps_context ** context_factory = NULL;
-static int context_factory_size = 0;
-static pthread_mutex_t context_factory_mutex = PTHREAD_MUTEX_INITIALIZER;
-
-#define MPS_CONTEXT_FACTORY_MAXIMUM_SIZE 0
-
 long int
 mps_context_get_minimum_precision (mps_context * s)
 {
@@ -119,30 +113,8 @@ mps_context_new ()
 {
   mps_context * ctx = NULL;
 
-  /* Try to get a low cost context from the factory */
-  pthread_mutex_lock (&context_factory_mutex);
-  if (context_factory_size > 0)
-    {
-      /* Pop out a context */
-      ctx = context_factory[--context_factory_size];
-
-      if (context_factory_size)
-        context_factory = mps_realloc (context_factory,
-                                       sizeof(mps_context*) * context_factory_size);
-      else
-        {
-          free (context_factory);
-          context_factory = NULL;
-        }
-    }
-  pthread_mutex_unlock (&context_factory_mutex);
-
-  /* Allocate the new mps_context and load default options */
-  if (!ctx)
-    {
-      ctx = (mps_context*)mps_malloc (sizeof(mps_context));
-      mps_context_init (ctx);
-    }
+  ctx = (mps_context*)mps_malloc (sizeof(mps_context));
+  mps_context_init (ctx);
 
   return ctx;
 }
@@ -173,18 +145,6 @@ mps_context_free (mps_context * s)
   free (s->bmpc);
   s->bmpc = NULL;
 
-  pthread_mutex_lock (&context_factory_mutex);
-
-  if (context_factory_size < MPS_CONTEXT_FACTORY_MAXIMUM_SIZE)
-    {
-      context_factory = mps_realloc (context_factory,
-                                     sizeof(mps_context*) * (context_factory_size + 1));
-      context_factory[context_factory_size++] = s;
-      pthread_mutex_unlock (&context_factory_mutex);
-      return;
-    }
-  pthread_mutex_unlock (&context_factory_mutex);
-
   if (s->initialized)
     mps_free_data (s);
 
@@ -676,6 +636,18 @@ mps_context_set_output_goal (mps_context * s, mps_output_goal goal)
   s->output_config->goal = goal;
 }
 
+/**
+ * @brief Restrict the search set for the roots.
+ *
+ * @param s The <code>mps_context</code> of the computation.
+ * @param set The search set for the roots.
+ */
+void
+mps_context_set_search_set(mps_context *s, mps_search_set set)
+{
+  s->output_config->search_set = set;
+}
+
 /**
  * @brief Set the value of the jacobi iterations switch in the MPSolve context.
  *
@@ -760,6 +732,19 @@ mps_context_set_log_stream (mps_context * s, FILE * logstr)
   s->logstr = logstr;
 }
 
+/**
+ * @brief Set root stream.
+ *
+ * @param s The <code>mps_context</code> of the current computation.
+ * @param rtstr The stream used to resume an interrupted computation
+ * or to load the approximations from a custom file.
+ */
+void
+mps_context_set_root_stream (mps_context * s, FILE * rtstr)
+{
+  s->rtstr = rtstr;
+}
+
 /**
  * @brief Set the phase from which the computation should start.
  *
@@ -904,3 +889,29 @@ mps_context_set_regeneration_driver (mps_context * s, mps_regeneration_driver *
 {
   s->regeneration_driver = rd;
 }
+
+/**
+ * @brief Set the number of threads.
+ *
+ * @param s The context where the change will have effect.
+ * @param n_threads The number of thread to be spawned.
+ */
+void mps_context_set_n_threads (mps_context *s, int n_threads)
+{
+  s->n_threads = n_threads;
+}
+
+/**
+* @brief Define which properties of the roots must be determined by MPSolve.
+ *
+ * @param s The context where the change will have effect.
+ * @param root_properties Possible values:
+ *  -# MPS_OUTPUT_PROPERTY_NONE
+ *  -# MPS_OUTPUT_PROPERTY_REAL
+ *  -# MPS_OUTPUT_PROPERTY_IMAGINARY
+ *  -# MPS_OUTPUT_PROPERTY_REAL | MPS_OUTPUT_PROPERTY_IMAGINARY
+ */
+void mps_context_set_root_properties (mps_context *s, char root_properties)
+{
+  s->output_config->root_properties = root_properties;
+}
