@@ -1,5 +1,5 @@
 /*
- * This file is part of MPSolve 3.2.1
+ * This file is part of MPSolve 3.2.2
  *
  * Copyright (C) 2001-2020, Dipartimento di Matematica "L. Tonelli", Pisa.
  * License: http://www.gnu.org/licenses/gpl.html GPL version 3 or higher
@@ -1524,7 +1524,7 @@ mps_cluster_check_detachment (mps_context * ctx, mps_clusterization * clusteriza
             {
               if (ctx->debug_level & MPS_DEBUG_CLUSTER)
                 MPS_DEBUG (ctx,
-                           "Cluster containing root %d was successfuly detached.", k);
+                           "Cluster containing root %d was successfully detached.", k);
 
               /* We need to stop marking this cluster as detached, that means
                * "experimental" in this context. */
