@@ -1,5 +1,5 @@
 /*
- * This file is part of MPSolve 3.2.1
+ * This file is part of MPSolve 3.2.2
  *
  * Copyright (C) 2001-2020, Dipartimento di Matematica "L. Tonelli", Pisa.
  * License: http://www.gnu.org/licenses/gpl.html GPL version 3 or higher
@@ -277,6 +277,14 @@ mps_secular_ga_fiterate (mps_context * s, int maxit, mps_boolean just_regenerate
   s->fp_iteration_time += mps_stop_timer (my_clock);
 #endif
 
+  for (i = 0; i < s->n; i++)
+    {
+      pthread_mutex_destroy (roots_mutex + i);
+      pthread_mutex_destroy (aberth_mutex + i);
+    }
+
+  pthread_mutex_destroy(&gs_mutex);  
+
   mps_thread_job_queue_free (queue);
   free (data);
   free (roots_mutex);
@@ -471,6 +479,12 @@ mps_secular_ga_diterate (mps_context * s, int maxit, mps_boolean just_regenerate
   s->dpe_iteration_time += mps_stop_timer (my_clock);
 #endif
 
+  for (i = 0; i < s->n; i++)
+    {
+      pthread_mutex_destroy (roots_mutex + i);
+      pthread_mutex_destroy (aberth_mutex + i);
+    }
+
   mps_thread_job_queue_free (queue);
   free (aberth_mutex);
   free (roots_mutex);
@@ -727,6 +741,12 @@ mps_secular_ga_miterate (mps_context * s, int maxit, mps_boolean just_regenerate
   s->mp_iteration_time += mps_stop_timer (my_clock);
 #endif
 
+  for (i = 0; i < s->n; i++)
+    {
+      pthread_mutex_destroy (roots_mutex + i);
+      pthread_mutex_destroy (aberth_mutex + i);
+    }
+
   mps_thread_job_queue_free (queue);
   free (aberth_mutex);
   free (roots_mutex);
